Module and Class Hierarchies

[show private | hide private]
[frames | no frames]

## Module Hierarchy

- `sqltriples`: A simple SQL-accessible RDF triple store.

## Class Hierarchy

- `__builtin__.object`: The most base type
  - `__builtin__.basestring`: Type basestring cannot be instantiated; it is the base for str and unicode.
    - `__builtin__.unicode`: unicode(string [, encoding[, errors]]) -> object
      - `sqltriples.Special`
        - `sqltriples.Literal`
        - `sqltriples.Namespace`
        - `sqltriples.URIRef`
  - `__builtin__.type`: type(object) -> the object's type type(name, bases, dict) -> a new type
- `exceptions.Exception`: Common base class for all exceptions.
  - `sqltriples.NotSupportedError`
- `sqltriples.Adapter`
  - `sqltriples.PgSQLAdapter`
  - `sqltriples.pysqlite2Adapter`
- `sqltriples.BNode`
- `sqltriples.Results`: A class representing a selection of results.
  - `sqltriples.CountableResults`: A class representing a count of some results.
  - `sqltriples.SingleResults`: A class representing a selection of single value results.
    - `sqltriples.Objects`: A class representing a selection of objects.
    - `sqltriples.Predicates`: A class representing a selection of predicates.
    - `sqltriples.Subjects`: A class representing a selection of subjects.
  - `sqltriples.Triples`: A class representing a selection of triples.
- `sqltriples.Subject`: A class representing a more conveniently accessible subject.
- `sqltriples.TripleStore`: A triple store whose contents are stored in an SQL-accessible database table.

Generated by Epydoc 2.1 on Tue Mar 21 02:02:07 2006 | http://epydoc.sf.net